@@ -906,6 +906,8 @@ class ServerOptions(Options):
                 expand(environment_str, expansions, 'environment'))
 
             directory = get(section, 'directory', None)
+            if directory is not None:
+                directory = directory.strip("\"'")
 
             logfiles = {}
 
@@ -1197,15 +1199,12 @@ class ServerOptions(Options):
         del self.pidhistory[pid]
 
     def waitpid(self):
-        stopped = []
         for pid in self.pidhistory:
             subprocess = self.pidhistory[pid]
             process = subprocess.process
             if process.poll() is not None:
-                stopped.append((pid, (process.poll(), process.message)))
-        if not stopped:
-            stopped.append((None, None))
-        return stopped
+                return (pid, (process.poll(), process.message))
+        return None, None
 
     @raise_not_implemented
     def set_rlimits_or_exit(self):
@@ -1325,9 +1324,9 @@ class ServerOptions(Options):
         try:
             return os.write(fd if type(fd) is int else fd.fileno(), as_bytes(data))
         except OSError:
-            if fd == 1 and not sys.stdout.isatty():
+            if fd == 1 and self.stdout is None or not self.stdout.isatty():
                 self.logger.info(data.rstrip())
-            elif fd == 2 and not sys.stderr.isatty():
+            elif fd == 2 and self.stderr is None or not self.stderr.isatty():
                 self.logger.error(data.rstrip())
             return 0
 
@@ -1385,6 +1384,7 @@ class ClientOptions(Options):
     username = None
     password = None
     history_file = None
+    xmlrpc_timeout = None
 
     def __init__(self):
         Options.__init__(self, require_configfile=False)
@@ -1396,6 +1396,7 @@ class ClientOptions(Options):
         self.configroot.supervisorctl.username = None
         self.configroot.supervisorctl.password = None
         self.configroot.supervisorctl.history_file = None
+        self.configroot.supervisorctl.xmlrpc_timeout = None
 
         from supervisor.supervisorctl import DefaultControllerPlugin
 
@@ -1411,7 +1412,9 @@ class ClientOptions(Options):
                  url, default="http://localhost:9001")
         self.add("username", "supervisorctl.username", "u:", "username=")
         self.add("password", "supervisorctl.password", "p:", "password=")
-        self.add("history", "supervisorctl.history_file", "r:", "history_file=")
+        self.add("history_file", "supervisorctl.history_file", "r:", "history-file=")
+        self.add("xmlrpc_timeout", "supervisorctl.xmlrpc_timeout", "x:", "xmlrpc-timeout=",
+                 handler=float, default=socket.getdefaulttimeout())
 
     def realize(self, *arg, **kw):
         Options.realize(self, *arg, **kw)
@@ -1458,6 +1461,11 @@ class ClientOptions(Options):
         history_file = parser.getdefault('history_file', section.history_file,
             expansions={'here': self.here})
 
+        # connection timeout
+        section.xmlrpc_timeout = parser.getdefault('xmlrpc_timeout', section.xmlrpc_timeout)
+        if section.xmlrpc_timeout is not None:
+            section.xmlrpc_timeout = float(section.xmlrpc_timeout)
+
         if history_file:
             history_file = normalize_path(history_file)
             section.history_file = history_file
@@ -1483,7 +1491,8 @@ class ClientOptions(Options):
             'http://127.0.0.1',
             transport=xmlrpc.SupervisorTransport(self.username,
                                                  self.password,
-                                                 self.serverurl)
+                                                 self.serverurl,
+                                                 self.xmlrpc_timeout)
         )
 
 
